FutureBuilder<T> class

Widget that builds itself based on the latest snapshot of interaction with a Future.

Inheritance

Constructors

FutureBuilder({Key? key, Future<T>? future, T? initialData, required AsyncWidgetBuilder<T> builder})
Creates a widget that builds itself based on the latest snapshot of interaction with a Future.
const

Properties

builder → AsyncWidgetBuilder<T>
final
correspondingTag → DomTagType?
Corresponding HTML tag to use to render this widget
no setterinherited
future → Future<T>?
The asynchronous computation to which this builder is currently connected, possibly null.
final
hashCode → int
The hash code for this object.
no setterinherited
initialData → T?
final
key → Key?
Keys help Rad identify which widgets have changed, are added, or are removed when a widget has multiple sibling widgets.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widgetCaptureEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in capturing phase.
no setterinherited
widgetEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in bubbling phase.
no setterinherited

Methods

createRenderElement(RenderElement parent) → RenderElement
Create element for current widget.
inherited
createState() → State<FutureBuilder<T>>
Creates the mutable state for this widget at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldUpdateWidget(Widget oldWidget) → bool
Whether to update current widget.
inherited
shouldUpdateWidgetChildren(Widget oldWidget, bool shouldUpdateWidget) → bool
Whether to update current widget's children.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

debugRethrowError ↔ bool
Whether the latest error received by the asynchronous computation should be rethrown or swallowed. This property is useful for debugging purposes.
getter/setter pair