Audio class

The Audio widget (HTML's audio tag).

Inheritance

Constructors

Audio({bool? autoPlay, bool? controls, CrossOriginType? crossOrigin, bool? loop, bool? muted, PreloadType? preload, String? src, Key? key, NullableElementCallback? ref, String? id, String? title, String? style, String? className, bool? hidden, String? innerText, Widget? child, List<Widget>? children, EventCallback? onClick, Map<String, String>? additionalAttributes})
const

Properties

additionalAttributes → Map<String, String>?
Any additional attributes.
finalinherited
autoPlay → bool?
A Boolean attribute: if specified, the audio will automatically begin playback as soon as it can do so, without waiting for the entire audio file to finish downloading.
final
child → Widget?
Child widget.
finalinherited
children → List<Widget>?
Multiple child widgets.
finalinherited
className → String?
The classes attribute specifies one or more class names for an dom node.
finalinherited
controls → bool?
f this attribute is present, the browser will offer controls to allow the user to control audio playback, including volume, seeking, and pause/resume playback.
final
correspondingTag → DomTagType
Corresponding HTML tag to use to render this widget
no setteroverride
crossOrigin → CrossOriginType?
This enumerated attribute indicates whether to use CORS to fetch the related audio file.
final
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool?
The hidden attribute is a boolean attribute. When present, it specifies that an dom node is not yet, or is no longer, relevant.
finalinherited
id → String?
ID of dom node.
finalinherited
innerText → String?
Element's inner text.
finalinherited
key → Key?
Keys help Rad identify which widgets have changed, are added, or are removed when a widget has multiple sibling widgets.
finalinherited
loop → bool?
A Boolean attribute: if specified, the audio player will automatically seek back to the start upon reaching the end of the audio.
final
muted → bool?
A Boolean attribute that indicates whether the audio will be initially silenced. Its default value is false.
final
onClick → EventCallback?
On click event listener.
finalinherited
preload → PreloadType?
This enumerated attribute is intended to provide a hint to the browser about what the author thinks will lead to the best user experience.
final
ref → NullableElementCallback?
Reference callback.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src → String?
The URL of the audio to embed. This is subject to HTTP access controls. This is optional; you may instead use the source element within the audio block to specify the audio to embed.
final
style → String?
The style attribute for inline CSS.
finalinherited
title → String?
The title attribute specifies extra information about an dom node.
finalinherited
widgetCaptureEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in capturing phase.
no setterinherited
widgetEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in bubbling phase.
no setterinherited

Methods

createRenderElement(RenderElement parent) → RenderElement
Create element for current widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldUpdateWidget(covariant Audio oldWidget) → bool
Whether to update current widget.
override
shouldUpdateWidgetChildren(Widget oldWidget, bool shouldUpdateWidget) → bool
Whether to update current widget's children.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited