EmbedTextTrack class

The EmbedTextTrack widget (HTML's track tag).

Inheritance

Constructors

EmbedTextTrack({bool? defaultAttribute, KindType? kind, String? label, String? src, String? srcLang, Key? key, NullableElementCallback? ref, String? id, String? title, String? style, String? className, bool? hidden, String? innerText, Widget? child, List<Widget>? children, EventCallback? onClick, Map<String, String>? additionalAttributes})
const

Properties

additionalAttributes → Map<String, String>?
Any additional attributes.
finalinherited
child → Widget?
Child widget.
finalinherited
children → List<Widget>?
Multiple child widgets.
finalinherited
className → String?
The classes attribute specifies one or more class names for an dom node.
finalinherited
correspondingTag → DomTagType
Corresponding HTML tag to use to render this widget
no setteroverride
defaultAttribute → bool?
This attribute indicates that the track should be enabled unless the user's preferences indicate that another track is more appropriate. This may only be used on one track element per media element.
final
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool?
The hidden attribute is a boolean attribute. When present, it specifies that an dom node is not yet, or is no longer, relevant.
finalinherited
id → String?
ID of dom node.
finalinherited
innerText → String?
Element's inner text.
finalinherited
key → Key?
Keys help Rad identify which widgets have changed, are added, or are removed when a widget has multiple sibling widgets.
finalinherited
kind → KindType?
How the text track is meant to be used. If omitted the default kind is subtitles. If the attribute contains an invalid value, it will use metadata (Versions of Chrome earlier than 52 treated an invalid value as subtitles).
final
label → String?
A user-readable title of the text track which is used by the browser when listing available text tracks.
final
onClick → EventCallback?
On click event listener.
finalinherited
ref → NullableElementCallback?
Reference callback.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src → String?
Address of the track (.vtt file). Must be a valid URL.
final
srcLang → String?
Language of the track text data.
final
style → String?
The style attribute for inline CSS.
finalinherited
title → String?
The title attribute specifies extra information about an dom node.
finalinherited
widgetCaptureEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in capturing phase.
no setterinherited
widgetEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in bubbling phase.
no setterinherited

Methods

createRenderElement(RenderElement parent) → RenderElement
Create element for current widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldUpdateWidget(covariant EmbedTextTrack oldWidget) → bool
Whether to update current widget.
override
shouldUpdateWidgetChildren(Widget oldWidget, bool shouldUpdateWidget) → bool
Whether to update current widget's children.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited