Form class

The Form widget (HTML's form tag).

Inheritance

Constructors

Form({String? name, String? acceptCharset, String? autoComplete, String? rel, String? action, FormMethodType? method, FormEncType? enctype, bool? noValidate, String? target, EventCallback? onSubmit, Key? key, NullableElementCallback? ref, String? id, String? title, String? style, String? className, bool? hidden, String? innerText, Widget? child, List<Widget>? children, EventCallback? onClick, Map<String, String>? additionalAttributes})
const

Properties

acceptCharset → String?
Space-separated character encodings the server accepts. The browser uses them in the order in which they are listed. The default value means the same encoding as the page.
final
action → String?
The URL that processes the form submission.
final
additionalAttributes → Map<String, String>?
Any additional attributes.
finalinherited
autoComplete → String?
Indicates whether input elements can by default have their values automatically completed by the browser.
final
child → Widget?
Child widget.
finalinherited
children → List<Widget>?
Multiple child widgets.
finalinherited
className → String?
The classes attribute specifies one or more class names for an dom node.
finalinherited
correspondingTag → DomTagType
Corresponding HTML tag to use to render this widget
no setteroverride
enctype → FormEncType?
MIME type of the form submission.
final
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool?
The hidden attribute is a boolean attribute. When present, it specifies that an dom node is not yet, or is no longer, relevant.
finalinherited
id → String?
ID of dom node.
finalinherited
innerText → String?
Element's inner text.
finalinherited
key → Key?
Keys help Rad identify which widgets have changed, are added, or are removed when a widget has multiple sibling widgets.
finalinherited
method → FormMethodType?
The HTTP method to submit the form with.
final
name → String?
Name of the form.
final
noValidate → bool?
This Boolean attribute indicates that the form shouldn't be validated when submitted.
final
onClick → EventCallback?
On click event listener.
finalinherited
onSubmit → EventCallback?
On submit event listener.
final
ref → NullableElementCallback?
Reference callback.
finalinherited
rel → String?
Creates a hyperlink or annotation depending on the value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → String?
The style attribute for inline CSS.
finalinherited
target → String?
Indicates where to display the response after submitting the form.
final
title → String?
The title attribute specifies extra information about an dom node.
finalinherited
widgetCaptureEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in capturing phase.
no setterinherited
widgetEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in bubbling phase.
no setteroverride

Methods

createRenderElement(RenderElement parent) → RenderElement
Create element for current widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldUpdateWidget(covariant Form oldWidget) → bool
Whether to update current widget.
override
shouldUpdateWidgetChildren(Widget oldWidget, bool shouldUpdateWidget) → bool
Whether to update current widget's children.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited