IFrame class

The IFrame widget (HTML's iframe tag).

Inheritance

Constructors

IFrame({String? src, String? srcDoc, String? name, String? allow, bool? allowFullscreen, bool? allowPaymentRequest, FetchPriorityType? fetchPriority, String? height, ReferrerPolicyType? referrerPolicy, String? width, Key? key, NullableElementCallback? ref, String? id, String? title, String? style, String? className, bool? hidden, String? innerText, Widget? child, List<Widget>? children, EventCallback? onClick, Map<String, String>? additionalAttributes})
const

Properties

additionalAttributes → Map<String, String>?
Any additional attributes.
finalinherited
allow → String?
Specifies a feature policy for the
final
allowFullscreen → bool?
This attribute is considered a legacy attribute.
final
allowPaymentRequest → bool?
Set to true if a cross-origin
final
child → Widget?
Child widget.
finalinherited
children → List<Widget>?
Multiple child widgets.
finalinherited
className → String?
The classes attribute specifies one or more class names for an dom node.
finalinherited
correspondingTag → DomTagType
Corresponding HTML tag to use to render this widget
no setteroverride
fetchPriority → FetchPriorityType?
Provides a hint of the relative priority to use when fetching the iframe document.
final
hashCode → int
The hash code for this object.
no setterinherited
height → String?
Height of IFrame container. Default is 150.
final
hidden → bool?
The hidden attribute is a boolean attribute. When present, it specifies that an dom node is not yet, or is no longer, relevant.
finalinherited
id → String?
ID of dom node.
finalinherited
innerText → String?
Element's inner text.
finalinherited
key → Key?
Keys help Rad identify which widgets have changed, are added, or are removed when a widget has multiple sibling widgets.
finalinherited
name → String?
A target-able name for the embedded browsing context.
final
onClick → EventCallback?
On click event listener.
finalinherited
ref → NullableElementCallback?
Reference callback.
finalinherited
referrerPolicy → ReferrerPolicyType?
Indicates which referrer to send when fetching the frame's resources
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src → String?
src of Iframe.
final
srcDoc → String?
Inline HTML to embed, overriding the src attribute. If a browser does not support the srcdoc attribute, it will fall back to the URL in the src attribute.
final
style → String?
The style attribute for inline CSS.
finalinherited
title → String?
The title attribute specifies extra information about an dom node.
finalinherited
widgetCaptureEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in capturing phase.
no setterinherited
widgetEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in bubbling phase.
no setterinherited
width → String?
Width of IFrame container. Default is 300.
final

Methods

createRenderElement(RenderElement parent) → RenderElement
Create element for current widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldUpdateWidget(covariant IFrame oldWidget) → bool
Whether to update current widget.
override
shouldUpdateWidgetChildren(Widget oldWidget, bool shouldUpdateWidget) → bool
Whether to update current widget's children.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited