Image class

The Image widget (HTML's img tag).

Inheritance

Constructors

Image({String? alt, CrossOriginType? crossOrigin, DecodingType? decoding, FetchPriorityType? fetchPriority, LoadingType? loading, ReferrerPolicyType? referrerPolicy, String? src, String? srcSet, String? width, String? height, Key? key, NullableElementCallback? ref, String? id, String? title, String? style, String? className, bool? hidden, String? innerText, Widget? child, List<Widget>? children, EventCallback? onClick, Map<String, String>? additionalAttributes})
const

Properties

additionalAttributes → Map<String, String>?
Any additional attributes.
finalinherited
alt → String?
Alt text for image.
final
child → Widget?
Child widget.
finalinherited
children → List<Widget>?
Multiple child widgets.
finalinherited
className → String?
The classes attribute specifies one or more class names for an dom node.
finalinherited
correspondingTag → DomTagType
Corresponding HTML tag to use to render this widget
no setteroverride
crossOrigin → CrossOriginType?
Indicates if the fetching of the image must be done using a CORS request.
final
decoding → DecodingType?
Provides an image decoding hint to the browser.
final
fetchPriority → FetchPriorityType?
Provides a hint of the relative priority to use when fetching the image.
final
hashCode → int
The hash code for this object.
no setterinherited
height → String?
final
hidden → bool?
The hidden attribute is a boolean attribute. When present, it specifies that an dom node is not yet, or is no longer, relevant.
finalinherited
id → String?
ID of dom node.
finalinherited
innerText → String?
Element's inner text.
finalinherited
key → Key?
Keys help Rad identify which widgets have changed, are added, or are removed when a widget has multiple sibling widgets.
finalinherited
loading → LoadingType?
Indicates how the image should be loaded.
final
onClick → EventCallback?
On click event listener.
finalinherited
ref → NullableElementCallback?
Reference callback.
finalinherited
referrerPolicy → ReferrerPolicyType?
A ReferrerPolicyType which referrer to use when fetching the resource.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src → String?
The image URL.
final
srcSet → String?
One or more strings separated by commas.
final
style → String?
The style attribute for inline CSS.
finalinherited
title → String?
The title attribute specifies extra information about an dom node.
finalinherited
widgetCaptureEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in capturing phase.
no setterinherited
widgetEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in bubbling phase.
no setterinherited
width → String?
final

Methods

createRenderElement(RenderElement parent) → RenderElement
Create element for current widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldUpdateWidget(covariant Image oldWidget) → bool
Whether to update current widget.
override
shouldUpdateWidgetChildren(Widget oldWidget, bool shouldUpdateWidget) → bool
Whether to update current widget's children.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited