OptionGroup class

The OptionGroup widget (HTML's optgroup tag).

Inheritance

Constructors

OptionGroup({String? label, bool? disabled, Key? key, NullableElementCallback? ref, String? id, String? title, String? style, String? className, bool? hidden, String? innerText, Widget? child, List<Widget>? children, EventCallback? onClick, Map<String, String>? additionalAttributes})
const

Properties

additionalAttributes → Map<String, String>?
Any additional attributes.
finalinherited
child → Widget?
Child widget.
finalinherited
children → List<Widget>?
Multiple child widgets.
finalinherited
className → String?
The classes attribute specifies one or more class names for an dom node.
finalinherited
correspondingTag → DomTagType
Corresponding HTML tag to use to render this widget
no setteroverride
disabled → bool?
If this Boolean attribute is set, none of the items in this option group is selectable. Often browsers grey out such control and it won't receive any browsing events, like mouse clicks or focus-related ones.
final
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool?
The hidden attribute is a boolean attribute. When present, it specifies that an dom node is not yet, or is no longer, relevant.
finalinherited
id → String?
ID of dom node.
finalinherited
innerText → String?
Element's inner text.
finalinherited
key → Key?
Keys help Rad identify which widgets have changed, are added, or are removed when a widget has multiple sibling widgets.
finalinherited
label → String?
The name of the group of options, which the browser can use when labeling the options in the user interface.
final
onClick → EventCallback?
On click event listener.
finalinherited
ref → NullableElementCallback?
Reference callback.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → String?
The style attribute for inline CSS.
finalinherited
title → String?
The title attribute specifies extra information about an dom node.
finalinherited
widgetCaptureEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in capturing phase.
no setterinherited
widgetEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in bubbling phase.
no setterinherited

Methods

createRenderElement(RenderElement parent) → RenderElement
Create element for current widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldUpdateWidget(covariant OptionGroup oldWidget) → bool
Whether to update current widget.
override
shouldUpdateWidgetChildren(Widget oldWidget, bool shouldUpdateWidget) → bool
Whether to update current widget's children.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited