Select class

The Select widget (HTML's select tag).

This HTML dom node represents a control that provides a menu of options.

Inheritance

Constructors

Select({String? autoComplete, String? name, String? form, String? size, bool? multiple, bool? required, bool? disabled, EventCallback? onChange, Key? key, NullableElementCallback? ref, String? id, String? title, String? style, String? className, bool? hidden, String? innerText, Widget? child, List<Widget>? children, EventCallback? onClick, Map<String, String>? additionalAttributes})
const

Properties

additionalAttributes → Map<String, String>?
Any additional attributes.
finalinherited
autoComplete → String?
A string providing a hint for a user agent's autocomplete feature.
final
child → Widget?
Child widget.
finalinherited
children → List<Widget>?
Multiple child widgets.
finalinherited
className → String?
The classes attribute specifies one or more class names for an dom node.
finalinherited
correspondingTag → DomTagType
Corresponding HTML tag to use to render this widget
no setteroverride
disabled → bool?
Whether Select is disabled.
final
form → String?
The form element to associate the select with (its form owner).
final
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool?
The hidden attribute is a boolean attribute. When present, it specifies that an dom node is not yet, or is no longer, relevant.
finalinherited
id → String?
ID of dom node.
finalinherited
innerText → String?
Element's inner text.
finalinherited
key → Key?
Keys help Rad identify which widgets have changed, are added, or are removed when a widget has multiple sibling widgets.
finalinherited
multiple → bool?
This Boolean attribute indicates that multiple options can be selected in the list.
final
name → String?
Associated Name. Used if Select is part of a form.
final
onChange → EventCallback?
On change event listener.
final
onClick → EventCallback?
On click event listener.
finalinherited
ref → NullableElementCallback?
Reference callback.
finalinherited
required → bool?
A Boolean attribute indicating that an option with a non-empty string value must be selected.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → String?
If the control is presented as a scrolling list box (e.g. when multiple is specified), this attribute represents the number of rows in the list that should be visible at one time.
final
style → String?
The style attribute for inline CSS.
finalinherited
title → String?
The title attribute specifies extra information about an dom node.
finalinherited
widgetCaptureEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in capturing phase.
no setterinherited
widgetEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in bubbling phase.
no setteroverride

Methods

createRenderElement(RenderElement parent) → RenderElement
Create element for current widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldUpdateWidget(covariant Select oldWidget) → bool
Whether to update current widget.
override
shouldUpdateWidgetChildren(Widget oldWidget, bool shouldUpdateWidget) → bool
Whether to update current widget's children.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited