TableDataCell class

The Table Data Cell widget (HTML's td tag).

Inheritance

Constructors

TableDataCell({int? rowSpan, int? colSpan, String? headers, Key? key, NullableElementCallback? ref, String? id, String? title, String? style, String? className, bool? hidden, String? innerText, Widget? child, List<Widget>? children, EventCallback? onClick, Map<String, String>? additionalAttributes})
const

Properties

abbr → String?
This attribute contains a short abbreviated description of the cell's content. Some user-agents, such as speech readers, may present this description before the content itself.
finalinherited
additionalAttributes → Map<String, String>?
Any additional attributes.
finalinherited
child → Widget?
Child widget.
finalinherited
children → List<Widget>?
Multiple child widgets.
finalinherited
className → String?
The classes attribute specifies one or more class names for an dom node.
finalinherited
colSpan → int?
This attribute contains a non-negative integer value that indicates for how many columns the cell extends. Its default value is 1. Values higher than 1000 will be considered as incorrect and will be set to the default value (1).
finalinherited
correspondingTag → DomTagType
Corresponding HTML tag to use to render this widget
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
headers → String?
This attribute contains a list of space-separated strings, each corresponding to the id attribute of the dom nodes that apply to this dom node.
finalinherited
hidden → bool?
The hidden attribute is a boolean attribute. When present, it specifies that an dom node is not yet, or is no longer, relevant.
finalinherited
id → String?
ID of dom node.
finalinherited
innerText → String?
Element's inner text.
finalinherited
key → Key?
Keys help Rad identify which widgets have changed, are added, or are removed when a widget has multiple sibling widgets.
finalinherited
onClick → EventCallback?
On click event listener.
finalinherited
ref → NullableElementCallback?
Reference callback.
finalinherited
rowSpan → int?
This attribute contains a non-negative integer value that indicates for how many rows the cell extends. Its default value is 1; if its value is set to 0, it extends until the end of the table section (TableHead, TableBody, TableFoot, even if implicitly defined), that the cell belongs to. Values higher than 65534 are clipped down to 65534..
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → ScopeType?
This enumerated attribute defines the cells that the header element relates to.
finalinherited
style → String?
The style attribute for inline CSS.
finalinherited
title → String?
The title attribute specifies extra information about an dom node.
finalinherited
widgetCaptureEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in capturing phase.
no setterinherited
widgetEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in bubbling phase.
no setterinherited

Methods

createRenderElement(RenderElement parent) → RenderElement
Create element for current widget.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldUpdateWidget(covariant Widget oldWidget) → bool
Whether to update current widget.
inherited
shouldUpdateWidgetChildren(Widget oldWidget, bool shouldUpdateWidget) → bool
Whether to update current widget's children.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited