Video class

The Video widget (HTML's video tag).

Inheritance

Constructors

Video({bool? autoPlay, bool? controls, CrossOriginType? crossOrigin, String? height, bool? loop, bool? muted, bool? playsInline, String? poster, PreloadType? preload, String? src, String? width, Key? key, NullableElementCallback? ref, String? id, String? title, String? style, String? className, bool? hidden, String? innerText, Widget? child, List<Widget>? children, EventCallback? onClick, Map<String, String>? additionalAttributes})
const

Properties

additionalAttributes → Map<String, String>?
Any additional attributes.
finalinherited
autoPlay → bool?
A Boolean attribute: if specified, the Video will automatically begin playback as soon as it can do so, without waiting for the entire Video file to finish downloading.
final
child → Widget?
Child widget.
finalinherited
children → List<Widget>?
Multiple child widgets.
finalinherited
className → String?
The classes attribute specifies one or more class names for an dom node.
finalinherited
controls → bool?
f this attribute is present, the browser will offer controls to allow the user to control Video playback, including volume, seeking, and pause/resume playback.
final
correspondingTag → DomTagType
Corresponding HTML tag to use to render this widget
no setteroverride
crossOrigin → CrossOriginType?
This enumerated attribute indicates whether to use CORS to fetch the related Video file.
final
hashCode → int
The hash code for this object.
no setterinherited
height → String?
The height of the video's display area.
final
hidden → bool?
The hidden attribute is a boolean attribute. When present, it specifies that an dom node is not yet, or is no longer, relevant.
finalinherited
id → String?
ID of dom node.
finalinherited
innerText → String?
Element's inner text.
finalinherited
key → Key?
Keys help Rad identify which widgets have changed, are added, or are removed when a widget has multiple sibling widgets.
finalinherited
loop → bool?
A Boolean attribute: if specified, the Video player will automatically seek back to the start upon reaching the end of the Video.
final
muted → bool?
A Boolean attribute that indicates whether the Video will be initially silenced. Its default value is false.
final
onClick → EventCallback?
On click event listener.
finalinherited
playsInline → bool?
A Boolean attribute indicating that the video is to be played "inline", that is within the element's playback area. Note that the absence of this attribute does not imply that the video will always be played in full screen.
final
poster → String?
A URL for an image to be shown while the video is downloading. If this attribute isn't specified, nothing is displayed until the first frame is available, then the first frame is shown as the poster frame.
final
preload → PreloadType?
This enumerated attribute is intended to provide a hint to the browser about what the author thinks will lead to the best user experience.
final
ref → NullableElementCallback?
Reference callback.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src → String?
The URL of the Video to embed. This is subject to HTTP access controls. This is optional; you may instead use the source element within the Video block to specify the Video to embed.
final
style → String?
The style attribute for inline CSS.
finalinherited
title → String?
The title attribute specifies extra information about an dom node.
finalinherited
widgetCaptureEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in capturing phase.
no setterinherited
widgetEventListeners → Map<DomEventType, EventCallback?>
Events that this widget is listening to in bubbling phase.
no setterinherited
width → String?
The width of the video's display area.
final

Methods

createRenderElement(RenderElement parent) → RenderElement
Create element for current widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldUpdateWidget(covariant Video oldWidget) → bool
Whether to update current widget.
override
shouldUpdateWidgetChildren(Widget oldWidget, bool shouldUpdateWidget) → bool
Whether to update current widget's children.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited